@@ -85,7 +85,7 @@ struct middle_ram_t : public middle_t {
     virtual ~middle_ram_t();
 
     void start(const options_t *out_options_) override;
-    void stop(void) override;
+    void stop(osmium::thread::Pool &pool) override;
     void analyze(void) override;
     void end(void) override;
     void commit(void) override;
