@@ -16,7 +16,7 @@
 
 namespace
 {
-    const char * short_options = "ab:cd:KhlmMp:suvU:WH:P:i:IE:C:S:e:o:O:xkjGz:r:V";
+    const char * short_options = "ab:cd:KhlmMp:suvU:WH:P:i:IE:C:S:e:o:O:xkjGz:r:VF:";
     const struct option long_options[] =
     {
         {"append",   0, 0, 'a'},
@@ -60,7 +60,7 @@ namespace
         {"number-processes", 1, 0, 205},
         {"drop", 0, 0, 206},
         {"unlogged", 0, 0, 207},
-        {"flat-nodes",1,0,209},
+        {"flat-nodes",1,0, 'F'},
         {"tag-transform-script",1,0,212},
         {"reproject-area",0,0,213},
         {0, 0, 0, 0}
@@ -96,9 +96,13 @@ namespace
                         required if you want to update with --append later.\n\
        -S|--style       Location of the style file. Defaults to\n");
         printf("\
-                        %s/default.style.\n", OSM2PGSQL_DATADIR);
+                        %s.\n", DEFAULT_STYLE);
         printf("%s", "\
        -C|--cache       Use up to this many MB for caching nodes (default: 800)\n\
+       -F|--flat-nodes  Specifies the flat file to use to persistently store node \n\
+                        information in slim mode instead of in PostgreSQL.\n\
+                        This file is a single > 40Gb large file. Only recommended\n\
+                        for full planet imports. Default is disabled.\n\
     \n\
     Database options:\n\
        -d|--database    The name of the PostgreSQL database to connect to.\n\
@@ -111,6 +115,7 @@ namespace
         if (verbose)
         {
             printf("%s", "\
+    \n\
     Hstore options:\n\
        -k|--hstore      Add tags without column to an additional hstore\n\
                         (key/value) column\n\
@@ -159,13 +164,11 @@ namespace
                         The default is \"sparse\"\n");
     #endif
         printf("%s", "\
-          --flat-nodes  Specifies the flat file to use to persistently store node \n\
-                        information in slim mode instead of in PostgreSQL.\n\
-                        This file is a single > 16Gb large file. Only recommended\n\
-                        for full planet imports. Default is disabled.\n\
     \n\
     Expiry options:\n\
        -e|--expire-tiles [min_zoom-]max_zoom    Create a tile expiry list.\n\
+                             Zoom levels must be larger than 0 and smaller\n\
+                             than 32.\n\
        -o|--expire-output filename  Output filename for expired tiles list.\n\
           --expire-bbox-size Max size for a polygon to expire the whole polygon,\n\
                              not just the boundary.\n\
@@ -266,7 +269,7 @@ options_t::options_t()
   projection(reprojection::create_projection(PROJ_SPHERE_MERC)), append(false),
   slim(false), cache(800), tblsmain_index(boost::none),
   tblsslim_index(boost::none), tblsmain_data(boost::none),
-  tblsslim_data(boost::none), style(OSM2PGSQL_DATADIR "/default.style"),
+  tblsslim_data(boost::none), style(DEFAULT_STYLE),
   expire_tiles_zoom(0), expire_tiles_zoom_min(0),
   expire_tiles_max_bbox(20000.0), expire_tiles_filename("dirty_tiles"),
   hstore_mode(HSTORE_NONE), enable_hstore_index(false), enable_multi(false),
@@ -377,15 +380,16 @@ options_t::options_t(int argc, char *argv[]): options_t()
             break;
         case 'e':
             if (!optarg || optarg[0] == '-') {
-                throw std::runtime_error("Missing argument for option -e. Zoom "
+                throw std::runtime_error("Missing argument for option --expire-tiles. Zoom "
                                          "levels must be positive.\n");
             }
             char *next_char;
             expire_tiles_zoom_min =
                 static_cast<uint32_t>(std::strtoul(optarg, &next_char, 10));
             if (expire_tiles_zoom_min == 0) {
-                throw std::runtime_error(
-                    "Missing zoom level for tile expiry.\n");
+                throw std::runtime_error("Bad argument for option --expire-tiles. "
+                                         "Minimum zoom level must be larger "
+                                         "than 0.\n");
             }
             // The first character after the number is ignored because that is the separating hyphen.
             if (*next_char == '-') {
@@ -395,18 +399,22 @@ options_t::options_t(int argc, char *argv[]): options_t()
                     char *after_maxzoom;
                     expire_tiles_zoom = static_cast<uint32_t>(
                         std::strtoul(next_char, &after_maxzoom, 10));
+                    if (expire_tiles_zoom == 0 || *after_maxzoom != '\0') {
+                        throw std::runtime_error("Invalid maximum zoom level "
+                                                 "given for tile expiry.\n");
+                    }
                 } else {
                     throw std::runtime_error(
                         "Invalid maximum zoom level given for tile expiry.\n");
                 }
+            } else if (*next_char == '\0') {
+                // end of string, no second zoom level given
+                expire_tiles_zoom = expire_tiles_zoom_min;
             } else {
                 throw std::runtime_error("Minimum and maximum zoom level for "
                                          "tile expiry must be separated by "
                                          "'-'.\n");
             }
-            if (expire_tiles_zoom < expire_tiles_zoom_min) {
-                expire_tiles_zoom = expire_tiles_zoom_min;
-            }
             break;
         case 'o':
             expire_tiles_filename = optarg;
@@ -472,7 +480,7 @@ options_t::options_t(int argc, char *argv[]): options_t()
         case 207:
             unlogged = true;
             break;
-        case 209:
+        case 'F':
             flat_node_cache_enabled = true;
             flat_node_file = optarg;
             break;
