@@ -6,6 +6,8 @@
 #include <utility>
 #include <vector>
 
+#include <osmium/thread/pool.hpp>
+
 #include "middle.hpp"
 #include "node-ram-cache.hpp"
 #include "osmdata.hpp"
@@ -39,9 +41,13 @@ int osmdata_t::node_add(osmium::Node const &node)
     mid->nodes_set(node);
 
     int status = 0;
-    for (auto &out : outs) {
-        status |= out->node_add(node);
+
+    if (!node.tags().empty()) {
+        for (auto &out : outs) {
+            status |= out->node_add(node);
+        }
     }
+
     return status;
 }
 
@@ -50,9 +56,13 @@ int osmdata_t::way_add(osmium::Way *way)
     mid->ways_set(*way);
 
     int status = 0;
-    for (auto& out: outs) {
-        status |= out->way_add(way);
+
+    if (!way->tags().empty()) {
+        for (auto& out: outs) {
+            status |= out->way_add(way);
+        }
     }
+
     return status;
 }
 
@@ -61,9 +71,12 @@ int osmdata_t::relation_add(osmium::Relation const &rel)
     mid->relations_set(rel);
 
     int status = 0;
-    for (auto& out: outs) {
-        status |= out->relation_add(rel);
+    if (!rel.tags().empty()) {
+        for (auto& out: outs) {
+            status |= out->relation_add(rel);
+        }
     }
+
     return status;
 }
 
@@ -390,35 +403,52 @@ void osmdata_t::stop() {
     // should be the same for all outputs
     const bool append = outs[0]->get_options()->append;
 
-    //threaded pending processing
-    pending_threaded_processor ptp(mid, outs, outs[0]->get_options()->num_procs,
-                                   append);
+    {
+        //threaded pending processing
+        pending_threaded_processor ptp(
+            mid, outs, outs[0]->get_options()->num_procs, append);
 
-    if (!outs.empty()) {
-        //This stage takes ways which were processed earlier, but might be
-        //involved in a multipolygon relation. They could also be ways that
-        //were modified in diff processing.
-        mid->iterate_ways( ptp );
+        if (!outs.empty()) {
+            //This stage takes ways which were processed earlier, but might be
+            //involved in a multipolygon relation. They could also be ways that
+            //were modified in diff processing.
+            mid->iterate_ways(ptp);
 
-        //This is like pending ways, except there aren't pending relations
-        //on import, only on update.
-        //TODO: Can we skip this on import?
-        mid->iterate_relations( ptp );
+            //This is like pending ways, except there aren't pending relations
+            //on import, only on update.
+            //TODO: Can we skip this on import?
+            mid->iterate_relations(ptp);
+        }
     }
 
+
     // Clustering, index creation, and cleanup.
     // All the intensive parts of this are long-running PostgreSQL commands
+    {
+        auto *opts = outs[0]->get_options();
+        osmium::thread::Pool pool(opts->parallel_indexing ? opts->num_procs : 1,
+                                  512);
 
-    std::vector<std::future<void>> futures;
+        if (opts->droptemp) {
+            // When dropping middle tables, make sure they are gone before
+            // indexing starts.
+            mid->stop(pool);
+        }
 
-    // XXX we might get too many parallel processes here
-    //     use osmium worker pool instead
-    for (auto& out: outs) {
-        futures.push_back(std::async(&output_t::stop, out.get()));
-    }
-    futures.push_back(std::async(&middle_t::stop, mid.get()));
+        for (auto &out : outs) {
+            out->stop(&pool);
+        }
 
-    for (auto& f: futures) {
-      f.get();
+        if (!opts->droptemp) {
+            // When keeping middle tables, there is quite a large index created
+            // which is better done after the output tables have been copied.
+            // Note that --disable-parallel-indexing needs to be used to really
+            // force the order.
+            mid->stop(pool);
+        }
+
+        // Waiting here for pool to execute all tasks.
+        // XXX If one of them has an error, all other will finish first,
+        //     which may take a long time.
     }
 }
