@@ -35,7 +35,7 @@ public:
     std::shared_ptr<output_t> clone(const middle_query_t* cloned_middle) const override;
 
     int start() override;
-    void stop() override;
+    void stop(osmium::thread::Pool *pool) override;
     void commit() override;
 
     void enqueue_ways(pending_queue_t &job_queue, osmid_t id, size_t output_id, size_t& added) override;
