@@ -29,8 +29,9 @@ void run_tests(options_t options, const std::string cache_type) {
 
     if (test_node_set(&mid_pgsql) != 0) { throw std::runtime_error("test_node_set failed."); }
 
+    osmium::thread::Pool pool(1);
     mid_pgsql.commit();
-    mid_pgsql.stop();
+    mid_pgsql.stop(pool);
   }
   {
     middle_pgsql_t mid_pgsql;
@@ -40,24 +41,32 @@ void run_tests(options_t options, const std::string cache_type) {
 
     if (test_nodes_comprehensive_set(&mid_pgsql) != 0) { throw std::runtime_error("test_nodes_comprehensive_set failed."); }
 
+    osmium::thread::Pool pool(1);
     mid_pgsql.commit();
-    mid_pgsql.stop();
+    mid_pgsql.stop(pool);
   }
   {
     middle_pgsql_t mid_pgsql;
     output_null_t out_test(&mid_pgsql, options);
 
     mid_pgsql.start(&options);
-    mid_pgsql.commit();
-    mid_pgsql.stop();
+    {
+        osmium::thread::Pool pool(1);
+        mid_pgsql.commit();
+        mid_pgsql.stop(pool);
+    }
+
     // Switch to append mode because this tests updates
     options.append = true;
     options.create = false;
     mid_pgsql.start(&options);
     if (test_way_set(&mid_pgsql) != 0) { throw std::runtime_error("test_way_set failed."); }
 
-    mid_pgsql.commit();
-    mid_pgsql.stop();
+    {
+        osmium::thread::Pool pool(1);
+        mid_pgsql.commit();
+        mid_pgsql.stop(pool);
+    }
   }
 }
 int main(int argc, char *argv[]) {
